@@ -1,5 +1,6 @@
 from sqlalchemy import Column, Integer, String, Float, Boolean, ForeignKey, Date, DateTime
-from sqlalchemy.orm import relationship
+from sqlalchemy.orm import relationship, validates
+from sqlalchemy.sql import func
 
 from .orm import get_base
 
@@ -421,6 +422,88 @@ class Assignment(Base):
         return self.title
 
 
+class QuestionBank(Base):
+    """
+    Банк вопросов
+    """
+    __tablename__ = 'assessment_question_banks'
+
+    # Идентификатор
+    id = Column(Integer, primary_key=True)
+
+    # Идентификатор контекста
+    context_id = Column(Integer)
+
+    # Тип контекста
+    # Возможные значения:
+    # - Course (Курс)
+    # - Account (Учетная запись)
+    context_type = Column(String(255))
+
+    @validates('context_type')
+    def validate_context_type(self, key, value):
+        """
+        Значением context_type может быть один из этих значении:
+        - Course (Курс)
+        - Account (Учетная запись)
+        """
+        assert value in ['Course', 'Account']
+        return value
+
+    # Наименование
+    title = Column(String(255))
+
+    # Статус
+    # Возможные значения:
+    # - active (Активный)
+    # - deleted (Удален)
+    workflow_state = Column(String(255), default='active')
+
+    @validates('workflow_state')
+    def validate_workflow_state(self, key, value):
+        """
+        Значением workflow_state может быть один из этих значении:
+        - active (Активный)
+        - deleted (Удален)
+        """
+        assert value in ['active', 'deleted']
+        return value
+
+    # Дата и время удаления
+    deleted_at = Column(DateTime)
+
+    @validates('deleted_at')
+    def validate_deleted_at(self, key, value):
+        """
+        deleted_at обязателен, если workflow_state='deleted'
+        """
+        if self.workflow_state == 'deleted':
+            assert value is not None
+
+        return value
+
+    # Дата и время создания
+    # server_default - Автоматически добавляет created_at при создании
+    created_at = Column(DateTime, server_default=func.now())
+
+    # Дата и время изменения
+    # onupdate - Автоматически изменяет updated_at на текущую дату и время
+    updated_at = Column(DateTime, onupdate=func.now())
+
+    # Неизвестное поле (Возможно идентификатор миграции)
+    migration_id = Column(String(255))
+
+    # Корневая учетная запись
+    root_account_id = Column(Integer)
+    root_account = relationship('Account')
+
+    def __repr__(self):
+        return f'<QuestionBank {self} (id={self.id} context_id={self.context_id} context_type={self.context_type} workflow_state={self.workflow_state})>'
+
+    def __str__(self):
+        return f'{self.title}'
+
+
 class Override(Base):
     """
     Модель "Назначение"
